-- 消息持久化数据表
CREATE TABLE webchat_ugc.`web_chat_message` (
     `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
     `sender` char(100) NOT NULL COMMENT '发送人',
     `receiver` char(100) NOT NULL COMMENT '接收人',
     `proxy_sender` char(100) DEFAULT NULL COMMENT '消息代理发送人（应用在群聊场景）',
     `message` text DEFAULT NULL COMMENT '消息内容',
     `image` varchar(300) DEFAULT NULL COMMENT '图片',
     `type` tinyint(1) DEFAULT 0 COMMENT '消息类型',
     `IS_READ` tinyint(1) DEFAULT 0 COMMENT '是否已读',
     `SEND_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '消息时间',
     `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
     `VERSION` int DEFAULT '0' COMMENT '版本',
     PRIMARY KEY (`ID`),
     KEY `INDEX_SENDER_PROXY_SENDER` (`sender`, `proxy_sender`),
     KEY `INDEX_RECEIVER` (`receiver`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='消息持久化数据表';


-- 红包信息表
CREATE TABLE webchat_ugc.`web_chat_red_packet` (
       `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
       `order_id` char(64) NOT NULL COMMENT '支付平台交易订单id',
       `sender` char(100) NOT NULL COMMENT '红包发送人',
       `receiver` char(100) NOT NULL COMMENT '接受账户（人、群、企业账户）',
       `type` int(4) NOT NULL COMMENT '红包类型 1 固定红包、2 拼手气',
       `count` int(4) NOT NULL COMMENT '红包个数',
       `cover` varchar(100) DEFAULT NULL COMMENT '红包封面',
       `blessing` varchar(50) DEFAULT NULL COMMENT '祝福语',
       `status` int(4) NOT NULL COMMENT '状态',
       `total_money` DECIMAL(10, 2) default '0.00' COMMENT '金额',
       `CREATE_BY` char(100) DEFAULT NULL COMMENT '创建人',
       `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
       `expire_date` datetime NOT NULL COMMENT '过期时间',
       `UPDATE_BY` char(100) DEFAULT NULL COMMENT '更新人',
       `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
       `VERSION` int DEFAULT '0' COMMENT '版本',
       PRIMARY KEY (`ID`),
       KEY `INDEX_ORDER_ID` (`order_id`),
       KEY `INDEX_SENDER` (`sender`),
       KEY `INDEX_STATUS_EXPIRE_DATE` (`status`, `expire_date`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='红包信息表';

-- 红包拆分记录明细表
CREATE TABLE webchat_ugc.`web_chat_red_packet_record` (
      `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
      `red_packet_id` bigint NOT NULL COMMENT '红包id',
      `user_id` char(100) NOT NULL COMMENT '领取人',
      `money` DECIMAL(10, 2) default '0.00' COMMENT '领取金额',
      `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
      PRIMARY KEY (`ID`),
      KEY `INDEX_RED_PACKET_ID` (`red_packet_id`),
      KEY `INDEX_USER_ID` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='红包拆分记录明细表';